Coverage report

Module | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | ---
pymend\__init__.py | 3 | 0 | 0 | 0 | 0 | 100%
pymend\__main__.py | 2 | 2 | 0 | 0 | 0 | 0%
pymend\const.py | 6 | 0 | 0 | 0 | 0 | 100%
pymend\docstring_parser\__init__.py | 5 | 0 | 0 | 0 | 0 | 100%
pymend\docstring_parser\common.py | 103 | 0 | 0 | 56 | 0 | 100%
pymend\docstring_parser\epydoc.py | 153 | 1 | 0 | 62 | 1 | 99%
pymend\docstring_parser\google.py | 216 | 9 | 0 | 112 | 4 | 96%
pymend\docstring_parser\numpydoc.py | 237 | 16 | 0 | 136 | 9 | 93%
pymend\docstring_parser\parser.py | 26 | 0 | 0 | 12 | 0 | 100%
pymend\docstring_parser\rest.py | 162 | 1 | 0 | 87 | 3 | 98%
pymend\docstring_parser\util.py | 41 | 0 | 0 | 22 | 2 | 97%
pymend\file_parser.py | 225 | 8 | 0 | 152 | 11 | 94%
pymend\files.py | 41 | 41 | 0 | 30 | 0 | 0%
pymend\output.py | 44 | 30 | 0 | 28 | 1 | 24%
pymend\pymend.py | 210 | 66 | 0 | 76 | 6 | 63%
pymend\pymendapp.py | 127 | 127 | 0 | 96 | 0 | 0%
pymend\report.py | 72 | 45 | 0 | 32 | 0 | 32%
pymend\types.py | 256 | 14 | 0 | 153 | 7 | 94%
Total | 1929 | 360 | 0 | 1054 | 44 | 79%

No items found using the specified filter.